Name:           reprepro
Version:        4.17.0
Release:        1%{?dist}
Summary:        Debian package repository producer

License:        GPLv2 and GPLv2+ and MIT
URL:            http://mirrorer.alioth.debian.org/
Source0:        http://http.debian.net/debian/pool/main/r/%{name}/%{name}_%{version}.orig.tar.gz

# Adjust Makefile to preserve timestamps on install commands
Patch0:         reprepro-preserve-timestamps-install.patch

# Make the test script check with rpm instead of dpkg
Patch1:         reprepro-convert-test-queries-from-dpkg-to-rpm.patch

# Adjust descriptions test to call unversioned db* executables
Patch2:         reprepro-descriptions-test-use-unversioned-db-cmds.patch

# DISABLED Patch3
# Adjust reprepro tests to work properly with /usr/bin binaries
Patch3:         reprepro-set-tests-to-work-with-usrmove.patch

# Adjust reprepro various2 test to read aptmethod 0.5 output properly
Patch4:         reprepro-adjust-various2-test-for-aptmethod-output.patch

BuildRequires:  gpgme-devel
BuildRequires:  libdb-devel
BuildRequires:  bzip2-devel, xz-devel, zlib-devel
BuildRequires:  libarchive-devel

# Tests cannot be run on Enterprise Linux
%if 0%{?fedora}
BuildRequires:  fakeroot, dpkg-dev, apt
BuildRequires:  lzma, libdb-utils
BuildRequires:  dash, ed
BuildRequires:  testtool

# These BuildRequires for tests are unavailable
#BuildRequires:  lunzip, python3-apt
%endif


%if 0%{?fedora}
# Some of reprepro's functionality depends on
# apt-methods, which is part of the apt package
Recommends:     apt

Suggests:       pinentry-curses, lzip
Suggests:       inoticoming
%endif

%description
reprepro is a tool to manage a repository of Debian packages
(.deb, .udeb, .dsc, ...). It stores files either being
injected manually or downloaded from some other repository
(partially) mirrored into one pool/ hierarchy.
Managed packages and files are stored in a Berkeley DB,
so no database server is needed.
Checking signatures of mirrored repositories and creating
signatures of the generated Package indices is supported.

This package also contains the changestool and rredtool helpers.

%package docs
Summary:        Extra documentation for %{name}
BuildArch:      noarch
# While Python scripts are included in here, we don't want Python as a dependency
AutoReq:        no
Requires:       %{name} = %{version}

%description docs
This package contains extra documentation for %{name},
including examples on how to use %{name}.

%prep
%setup -q
%patch0 -p0

# Patches for tests
%patch1 -p0
%patch2 -p0
#patch3 -p0
%patch4 -p0



%build
export CFLAGS="%{optflags} -DSTD_METHOD_DIR='\"%{_libdir}/apt/methods\"'"
export CXXFLAGS="%{optflags} -DSTD_METHOD_DIR='\"%{_libdir}/apt/methods\"'"
%configure --with-liblzma --with-libgpgme --with-libbz2 --with-libarchive
make %{?_smp_mflags}


%install

# docs/sftp.py is marked as executable when it shouldn't be
chmod 644 docs/sftp.py

install -p -D -m 644 docs/reprepro.bash_completion %{buildroot}%{_sysconfdir}/bash_completion.d/reprepro
%make_install

# Only run this on Fedora, as we can't satisfy basic dependencies on Enterprise Linux
%if 0%{?fedora}
# The check tests require python3-apt, which is not present in apt 0.5
# As no one has forward ported APT-RPM to the current version (1.10.x at this time),
# some of these tests are broken, as they depend on it to work properly.
# Some tests also depend on lunzip, which is not packaged.
# Two tests fail, even though the test suite won't fail the build:
# * packagediff (depends on py3 module apt-pkg, part of python3-apt)
# * uncompress (depends on lunzip)
%check
./tests/test.sh
%endif

%files
%{_sysconfdir}/bash_completion.d/reprepro
%{_bindir}/changestool
%{_bindir}/reprepro
%{_bindir}/rredtool
%{_mandir}/man1/*.1.gz
%doc AUTHORS TODO NEWS README ChangeLog
%license COPYING

%files docs
%doc docs/
%license COPYING



%changelog
* Tue Feb  9 2016 Neal Gompa <ngompa13{%}gmail{*}com> - 4.17.0-1
- Update to latest upstream version

* Mon Aug 24 2015 Neal Gompa <ngompa13{%}gmail{*}com> - 4.16.0-4
- Replace patch with compile definition for apt-methods path

* Mon Aug 24 2015 Neal Gompa <ngompa13{%}gmail{*}com> - 4.16.0-3
- Switch ifarch conditional for __isa_bits conditional

* Mon Aug 24 2015 Neal Gompa <ngompa13{%}gmail{*}com> - 4.16.0-2
- Disable running the tests on Enterprise Linux
- Ensure docs subpackage pulls in main package

* Sun Aug 23 2015 Neal Gompa <ngompa13{%}gmail{*}com> - 4.16.0-1
- Initial packaging based on Debian packaging info
- Patch to make reprepro see apt-methods on 64-bit properly
- Patches to get tests mostly working
